@@ -126,13 +126,13 @@ class migrateUsers(_shareData):
         """Get data system users in new system"""
         fileName = pathJoin(self.prefixNewSystem, self.filePasswd)
         return [x for x in self.getData(fileName=fileName) 
-            if self._reNumb.match(x[2]) and (int(x[2] > self.maxId) or int(x[2]) < self.minId)]
+            if self._reNumb.match(x[2]) and (int(x[2]) > self.maxId or int(x[2]) < self.minId)]
 
     def getThisDataSystemUsers(self):
         """Get data system users in this system"""
         fileName = self.filePasswd
         return [x for x in self.getData(fileName=fileName) 
-            if self._reNumb.match(x[2]) and (int(x[2] > self.maxId) or int(x[2]) < self.minId)]
+            if self._reNumb.match(x[2]) and (int(x[2]) > self.maxId or int(x[2]) < self.minId)]
 
     def getNewProcessedData(self, migrateUsers=()):
         """Get processed data migrate users in new system"""
