@@ -22,7 +22,7 @@ from calculate.lib.datavars import (Variable, ReadonlyVariable,
 from calculate.lib.utils.common import getValueFromCmdLine, CmdlineParams
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.files import readFile, readLinesFile
-from calculate.install.distr import DistributiveError
+from ..distr import DistributiveError
 import glob
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -88,14 +88,12 @@ class VariableOsAudioAvailable(Variable):
             with image as distr:
                 try:
                     distrPath = image.getDirectory()
-                    return map(lambda x: x[0::2],
-                               filter(lambda x: not x[1] or isPkgInstalled(x[1],
-                                                                           prefix=distrPath),
-                                      mapAudioConf))
+                    return [x[0::2] for x 
+                        in mapAudioConf 
+                        if not x[1] or isPkgInstalled(x[1], prefix=distrPath)]
                 except DistributiveError as e:
                     pass
-        return sorted(map(lambda x: x[0::2], mapAudioConf[-1:]),
-                      key=lambda x: x[1])
+        return sorted((x[0::2] for x in mapAudioConf[-1:]), key=lambda x: x[1])
 
 
 class VariableOsAudioCardMap(ReadonlyVariable):
