@@ -24,7 +24,7 @@ from calculate.lib.utils.device import humanreadableSize
 from calculate.lib.utils import partition
 from calculate.lib.utils.files import (readLinesFile)
 from calculate.lib.utils.mount import isMount, try_umount
-from calculate.install.fs_manager import FileSystemManager
+from ..fs_manager import FileSystemManager
 from calculate.lib.utils.tools import Sizes, traverse
 from itertools import *
 
@@ -71,7 +71,7 @@ class AutopartitionError(Exception):
     pass
 
 
-class SchemeOpt(object):
+class SchemeOpt():
     Swap = "swap"
     Update = "update"
     UEFI = "uefi"
@@ -98,9 +98,7 @@ class VariableHrMemorySize(ReadonlyVariable):
 
     def get(self):
         reMemTotal = re.compile(r'^MemTotal:\s*(\d+)\s*kB$')
-        totalMemList = filter(lambda x: x,
-                              map(reMemTotal.search,
-                                  readLinesFile('/proc/meminfo')))
+        totalMemList = [x for x in map(reMemTotal.search, readLinesFile('/proc/meminfo')) if x]
         if totalMemList:
             size = int(totalMemList[0].group(1)) * Sizes.K
             return str(size)
@@ -212,7 +210,7 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
         self.label = _("Devices for install")
 
     def get(self):
-        choiceVal = map(lambda x: x[0], self.choice())
+        choiceVal = [x[0] for x in self.choice()]
         devicesTypes = self.Select(['os_device_dev','os_device_type'],
             where='os_device_dev', _in=choiceVal)
         notFlashDevices = [x[0] for x in devicesTypes if x[1] != 'flash']
@@ -255,8 +253,9 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
     def checkOnRaid(self, valuelist):
         disks = self.Select('os_disk_dev',
                             where='os_disk_parent', _in=valuelist)
-        raids = filter(None, self.Select('os_disk_raid',
-                                         where='os_disk_dev', _in=disks))
+        raids = [x for x 
+                    in self.Select('os_disk_raid', where='os_disk_dev', _in=disks) 
+                if x]
         raidDisks = self.Select('os_disk_dev', where='os_disk_raid', _in=raids)
         raidDevices = self.Select('os_disk_parent',
                                   where='os_disk_dev',
@@ -441,7 +440,7 @@ class VariableClAutopartitionDefaultFormat(Variable):
     type = "choice"
 
     def get(self):
-        return FileSystemManager.defaultFS['hdd']
+        return FileSystemManager.get_default_fs(self, 'hdd')
 
     def choice(self):
         allfs = set([k for k,v in FileSystemManager.supportFS.items()
@@ -689,17 +688,29 @@ class VariableClAutopartitionLvmVgname(Variable):
     """
 
     def get(self):
+        # def generateName(startName):
+        #     yield startName
+        #     for i in count(20):
+        #         yield "%s%d" % (startName, i)
+        
+        # instead this just so there won't be an infinite loop
         def generateName(startName):
             yield startName
-            for i in count(20):
+            for i in range(20, 1000):
                 yield "%s%d" % (startName, i)
-
+                
+    
         for name in generateName("calculate"):
+            
             disks = self.Select('os_lvm_pvname', where='os_lvm_vgname', eq=name)
             devices = self.Select('os_disk_parent',
                                   where='os_disk_dev', _in=disks)
+            
             if set(devices) <= set(self.Get('cl_autopartition_device')):
                 return name
+        
+        #TODO should replace this
+        raise Exception
 
 
 class VariableClAutopartitionDiskData(ReadonlyTableVariable):
@@ -772,10 +783,10 @@ class VariableClAutopartitionDiskSize(DiskFilter, ReadonlyVariable):
     field = "disk_size"
 
     def get(self):
-        return map(str, super(VariableClAutopartitionDiskSize, self).get())
+        return [str(x) for x in super().get()]
 
     def humanReadable(self):
-        return map(humanreadableSize, self.Get())
+        return [humanreadableSize(x) for x in self.Get()]
 
 
 class VariableClAutopartitionDiskDataFull(ReadonlyTableVariable):
@@ -864,10 +875,10 @@ class VariableClAutopartitionDiskSizeFull(ReadonlyVariable):
 
     def get(self):
         var_factory = self.Get('cl_autopartition_factory')
-        return map(str, var_factory.disk_size)
+        return [str(x) for x in var_factory.disk_size]
 
     def humanReadable(self):
-        return map(humanreadableSize, self.Get())
+        return [humanreadableSize(x) for x in self.Get()]
 
 
 class VariableClAutopartitionRaid(ReadonlyVariable):
@@ -1016,7 +1027,7 @@ class VariableClAutopartitionBindPath(FieldValue, ReadonlyVariable):
     column = 0
 
     def get(self):
-        return list(super(VariableClAutopartitionBindPath, self).get())
+        return list(super().get())
 
 class VariableClAutopartitionBindMountpoint(FieldValue, ReadonlyVariable):
     """
@@ -1027,4 +1038,4 @@ class VariableClAutopartitionBindMountpoint(FieldValue, ReadonlyVariable):
     column = 1
 
     def get(self):
-        return list(super(VariableClAutopartitionBindMountpoint, self).get())
+        return list(super().get())
