@@ -23,7 +23,7 @@ from operator import itemgetter
 from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
                                     CommonVariableError)
 from calculate.lib.utils.common import (getSupportArch, getTupleVersion,
-                                        cmpVersion)
+                                        cmpVersion, cmp)
 from calculate.lib.utils.files import listDirectory, pathJoin
 from calculate.lib.variables.linux import Linux
 from ..distr import (Distributive, PartitionDistributive,
@@ -177,11 +177,7 @@ class DistroRepository(Linux):
                    'partdir': -3,
                    'dir': -4}
         
-        # return cmp(mapExts.get(exts[0], -4), mapExts.get(exts[1], -4))
-        #no cmp in python3, instead do (a > b) - (a < b) 
-        return (mapExts.get(exts[0], -4) > mapExts.get(exts[1], -4)) - \
-            (mapExts.get(exts[0], -4) < mapExts.get(exts[1], -4)) 
-        
+        return cmp(mapExts.get(exts[0], -4), mapExts.get(exts[1], -4))
 
 
     @staticmethod
@@ -503,7 +499,7 @@ class VariableClImagePath(ReadonlyVariable):
             livedistr = []
         # search all partition for source installation distributive
         rootDev = self.Get('os_install_root_dev')
-        livedistr = [x[0] for x 
+        livedistr += [x[0] for x 
             in zip(self.Get('os_disk_dev'), self.Get('os_disk_content')) 
             if " live" in x[1] and x[0] != rootDev]
         # add to standard path 
