@@ -36,7 +36,7 @@ from calculate.lib.utils.files import readLinesFile
 from calculate.lib.utils.common import (getKernelUid, getTupleVersion,
                                         getValueFromCmdLine, CmdlineParams)
 from itertools import *
-from calculate.install.distr import DistributiveError
+from ..distr import DistributiveError
 
 
 class VariableOsInstallKernelScheduler(Variable):
@@ -77,7 +77,7 @@ class VariableOsInstallKernelScheduler(Variable):
         else:
             currentScheduler = getValueFromCmdLine(
                 CmdlineParams.IOScheduler)
-            if currentScheduler in map(lambda x: x[0], self.choice()):
+            if currentScheduler in (x[0] for x in self.choice()):
                 return currentScheduler
         return self.Get('os_install_kernel_schedule_default')
 
@@ -104,7 +104,7 @@ class VariableOsInstallKernelScheduler(Variable):
             return _("I/O scheduler unavailable for Flash install")
 
 
-class KernelConfig(object):
+class KernelConfig():
     def __init__(self, kernel_config):
         self.data = readFile(kernel_config).split('\n')
         self.config = kernel_config
@@ -224,9 +224,9 @@ class VariableOsInstallKernelScheduleData(ReadonlyTableVariable):
                       'CONFIG_IOSCHED_NOOP=y': 'noop',
                       'CONFIG_IOSCHED_CFQ=y': 'cfq',
                       'CONFIG_IOSCHED_DEADLINE=y': 'deadline'}
-        installed = map(schedulers.get,
-                        filter(lambda x: x in schedulers,
-                               self.Get('os_install_kernel_config'))) or ['cfq']
+        installed = [schedulers.get(x) for x 
+            in self.Get('os_install_kernel_config') 
+            if x in schedulers] or ['cfq']
         return [[x, "on" if x in installed else "off"]
                 for x in sorted(schedulers.values())]
 
@@ -336,15 +336,13 @@ class KernelHelper(VariableInterface):
 
     def getFilesByType(self, pathname, descr):
         """Get files from "pathname" has "descr" in descriptions"""
-        filelist = map(lambda x: path.join(pathname, x), os.listdir(pathname))
+        filelist = [path.join(pathname, x) for x in os.listdir(pathname)]
         ftype = typeFile(magic=MAGIC_COMPRESS | MAGIC_SYMLINK).getMType
-        filesWithType = map(lambda x: (x, ftype(x)),
-                            filter(path.exists,
-                                   filelist))
-        return filter(lambda x: x[1] and descr in x[1], filesWithType)
+        filesWithType = [(x, ftype(x)) for x in filelist if path.exists(x)]
+        return [x for x in filesWithType if x[1] and descr in x[1]]
 
     def getInitrdFiles(self, pathname):
-        filelist = map(lambda x: path.join(pathname, x), os.listdir(pathname))
+        filelist = [path.join(pathname, x) for x in os.listdir(pathname)]
         return [x for x in filelist if path.exists(x) and InitrdFile.is_cpio(x)]
 
     def getInitrd(self, arch, shortname, chroot, kernel, suffix="",
@@ -372,14 +370,12 @@ class KernelHelper(VariableInterface):
 
             bootdir = path.join(chroot, 'boot')
             initramfsFiles = self.getInitrdFiles(bootdir)
-            initramfsWithVer = \
-                filter(lambda x: (kernelVersion in x[1] or
-                                  origKernelVer in x[1]) and \
-                                 x[0].endswith(suffix) and \
-                                 (
-                                 not notsuffix or not x[0].endswith(notsuffix)),
-                       map(lambda x: (x, initrd_version_by_name(x)),
-                           initramfsFiles))
+            initramfsWithVer = [x for x 
+                in [(y, initrd_version_by_name(y)) for y in initramfsFiles]
+                if (kernelVersion in x[1] or
+                    origKernelVer in x[1]) and 
+                    x[0].endswith(suffix) and 
+                    (not notsuffix or not x[0].endswith(notsuffix))]
             if initramfsWithVer:
                 return path.split(min(initramfsWithVer,
                                       key=itemgetter(0))[0])[-1]
@@ -397,18 +393,28 @@ class VariableOsInstallKernel(ReadonlyVariable, KernelHelper):
         validKernel = listDirectory(modulesdir)
         kernelFiles = self.getFilesByType(bootdir, "Linux kernel")
         installMarch = self.Get('os_install_arch_machine')
-        kernelsWithVer = \
-            map(lambda x: (
-            x[0], (getTupleVersion("".join(x[1].groups()[0:3:2])),
-                   path.getmtime(x[0]))),
-                # convert version to tuple( versionTuple, mtime)
-                # version detect, for this version lib contains moudules
-                # kernel arch equal install arch
-                ifilter(lambda x: x[1] and x[1].group() in validKernel and
-                                  installMarch in x[0].rpartition('/')[2],
-                        # (filename,version)
-                        imap(lambda x: (x[0], self.reFindVer.search(x[1])),
-                             kernelFiles)))
+        # kernelsWithVer = \
+        #     list(map(lambda x: (
+        #     x[0], (getTupleVersion("".join(x[1].groups()[0:3:2])),
+        #            path.getmtime(x[0]))),
+        #         # convert version to tuple( versionTuple, mtime)
+        #         # version detect, for this version lib contains moudules
+        #         # kernel arch equal install arch
+        #         filter(lambda x: x[1] and x[1].group() in validKernel and
+        #                           installMarch in x[0].rpartition('/')[2],
+        #                 # (filename,version)
+        #                 map(lambda x: (x[0], self.reFindVer.search(x[1])),
+        #                      kernelFiles))))
+        kernelsWithVer = [(x[0], 
+                        (getTupleVersion("".join(x[1].groups()[0:3:2])),
+                        path.getmtime(x[0]))) for x 
+                        # convert version to tuple( versionTuple, mtime)
+                        # version detect, for this version lib contains moudules
+                        # kernel arch equal install arch
+                            in [y for y
+                                # (filename,version) 
+                                in [(z[0], self.reFindVer.search(z[1])) for z in kernelFiles] 
+                            if y[1] and y[1].group() in validKernel and installMarch in y[0].rpartition('/')[2]]]   
         if kernelsWithVer:
             return path.split(max(kernelsWithVer, key=itemgetter(1))[0])[-1]
         else:
@@ -469,9 +475,8 @@ class VariableOsInstallKernelCpufreq(ReadonlyVariable):
 
     def get(self):
         """Get cpufreq (and other from modules_3= param) from conf.d/modules"""
-        cpufreqmods = map(lambda x: x.partition('=')[2].strip("\n '\""),
-                          filter(lambda x: x.startswith('modules_3'),
-                                 readLinesFile('/etc/conf.d/modules')))
+        cpufreqmods = [x.partition('=')[2].strip("\n '\"") for x 
+            in readLinesFile('/etc/conf.d/modules') if x.startswith('modules_3')]
         if cpufreqmods:
             return cpufreqmods[0]
         else:
